==> dl.php?src=linea21_1_8.zip: linea21/templates/admin/2015/header.php <==
<?php
/**
 * @package linea21\templates\admin
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<!-- header -->
<header id="header" role="banner" class="line">
<div id="tools" class="line">
	<div class="mod left" id="sitename">
		<?php echo SITE_NAME; ?>
	</div>
	<div class="mod right" id="bienvenue">
		
		<?php
	  if($l21auth->GetSessionElement('firstname')) $title= ucfirst($l21auth->GetSessionElement('firstname'));
	  else $title= $l21auth->GetSessionElement('login');
	
	  echo _t('header','welcome');
	  ?>
	  <span><?php echo $title; ?></span>, <a href="logout.php" class="logout"><i class="icon-off icon-big"></i><?php echo _t('header','deconnexion');?></a>
	  
	  <a href="../public/index.php" title="<?php echo mb_ucfirst(_t('divers', 'back_public')); ?>" id="goto-front"><i class="icon-home icon-big"></i> <span><?php echo mb_ucfirst(_t('divers', 'back_public')); ?></span></a> | 
	  <a href="../admin/search.php?rub=home" title="<?php echo _t('menu_alt','do_search'); ?>" id="searchDiv"><i class="icon-search icon-big"></i></a>
		<div class="mod left" id="containersearch">
  	<form method="post" action="search.php">
  		<div>
	  		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
	  		<input type="submit" id="gosearch"   name="valid" value="" />
  		</div>
  	</form>
	</div> <!-- closing  #containersearch div -->
	</div> <!-- closing  #bienvenue div -->
</div> <!-- closing  #tools div -->
<?php 
include_once("common_menu.php");
?>
</header>
<!--end header -->

==> dl.php?src=linea21_2_0_0.zip: linea21/templates/admin/2015/header.php <==
<?php
/**
 * @package linea21\templates\admin
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<!-- header -->
<header id="header" class="line">
<div id="tools" class="line">
	<div class="mod left" id="sitename">
		<?php echo SITE_NAME; ?>
	</div>
	<div class="mod right" id="bienvenue">
		
		<?php
	  if($l21auth->GetSessionElement('firstname')) $title= ucfirst($l21auth->GetSessionElement('firstname'));
	  else $title= $l21auth->GetSessionElement('login');
	
	  echo _t('header','welcome');
	  ?>
	  <span><?php echo $title; ?></span>, <a href="logout.php" class="logout"><i class="icon-off icon-big"></i><?php echo _t('header','deconnexion');?></a>
	  
	  <a href="../public/index.php" title="<?php echo mb_ucfirst(_t('divers', 'back_public')); ?>" id="goto-front"><i class="icon-home icon-big"></i> <span><?php echo mb_ucfirst(_t('divers', 'back_public')); ?></span></a> | 
	  <a href="../admin/search.php?rub=home" title="<?php echo _t('menu_alt','do_search'); ?>" id="searchDiv"><i class="icon-search icon-big"></i></a>
		<div class="mod left" id="containersearch">
  	<form method="post" action="search.php">
  		<div>
	  		<input type="text" class="searchincome" name="search" id="searchincome"  accesskey="s" value="<?php echo _t('menu_alt','search_here'); ?>" onclick="if (this.defaultValue==this.value) this.value=''" onblur="if (this.value=='') this.value=this.defaultValue" />
	  		<input type="submit" id="gosearch"   name="valid" value="" />
  		</div>
  	</form>
	</div> <!-- closing  #containersearch div -->
	</div> <!-- closing  #bienvenue div -->
</div> <!-- closing  #tools div -->
<?php 
include_once("common_menu.php");
?>
</header>
<!--end header -->
